@@ -126,7 +126,7 @@ class ApiResource(object):
                 if isinstance(x, unicode) else x
             params = {
                 sanitize_param_str(k): sanitize_param_str(params[k])
-                for k in params
+                for k in params if params[k] is not None
             }
 
         # Set up the headers.
@@ -493,7 +493,7 @@ class Client(CreatableResource,
             x if isinstance(x, (str, unicode, )) else
             CreditCardPayment.deserialize(x) if x['type'] == 'creditcard' else
             DebitPayment.deserialize(x) for x in payments if x is not None
-        ],
+        ] if payments is not None else [],
     }
 
 
@@ -599,8 +599,7 @@ class CreditCardPayment(Payment,
             if not isinstance(client, (str, unicode, )):
                 raise ValueError('invalid unique client ID: %r' % (client))
 
-        return cls._create(type='creditcard',
-                           token=token,
+        return cls._create(token=token,
                            client=client,
                            api_key=api_key)
 
@@ -632,8 +631,7 @@ class DebitPayment(Payment,
             if not isinstance(client, (str, unicode, )):
                 raise ValueError('invalid unique client ID: %r' % (client))
 
-        return cls._create(type='debit',
-                           token=token,
+        return cls._create(token=token,
                            client=client,
                            api_key=api_key)
 
@@ -767,7 +765,10 @@ class Transaction(MappableResource,
         'payment': lambda x: None if x is None else
         CreditCardPayment.deserialize(x) if x['type'] == 'creditcard' else
         DebitPayment.deserialize(x),
-        'refunds': lambda refunds: [Refund.deserialize(r) for r in refunds] if
+        'refunds': lambda refunds: [
+            Refund.deserialize(r) if isinstance(r, dict) else r
+            for r in refunds
+        ] if
         isinstance(refunds, list) else [],
         'expire_month': parse_int_if_not_none,
         'expire_year': parse_int_if_not_none,
@@ -893,8 +894,10 @@ class Refund(MappableResource, DetailableResource):
         'created_at': parse_datetime,
         'updated_at': parse_datetime,
         'amount': lambda x: int(x),
-        'transaction': lambda x: None if x is None else
-        Transaction.deserialize(x),
+        'transaction_id': lambda x: x if isinstance(x, (unicode, str, ))
+        else None,
+        'transaction': lambda x: Transaction.deserialize(x)
+        if isinstance(x, dict) else None,
     }
 
 
